@@ -28,6 +28,7 @@ import matplotlib as mpl
 mpl.use('pgf')
 import matplotlib.pyplot as plt
 from mpl_toolkits.mplot3d import Axes3D
+import matplotlib.gridspec as gridspec
 from matplotlib import animation
 from scipy import interpolate
 import os
@@ -186,7 +187,7 @@ def save_proj(x,y,ytot, k,Ruc, eigvec,freq,n,namedir,masses, params, max_Z):
     except FileExistsError:
         a = 1
 
-#    mpl.rcParams.update(pgf_with_latex)
+    mpl.rcParams.update(pgf_with_latex)
     plt.ioff()
     fig,ax = plt.subplots()
     #graph2, = ax.plot(x,ytot,'--',label='k-point DOS', color='grey')
@@ -325,8 +326,7 @@ def plot_k2(f, data, data_projected, indexes,freqs, max_Z, branches,  freq_res,
     plt.rcParams['axes.linewidth'] = 2
 #    plt.show()
     plt.suptitle('Spectrum branches '+str(branches))
-    fig.savefig('spectrum_branches_'+str(branches)+'.pdf')
-    fig.savefig('spectrum_branches_'+str(branches)+'.png')
+    fig.savefig('plot5_'+str(branches)+'.pdf')
     return
 
 
@@ -628,7 +628,7 @@ def plot3(Ts, frequencies, modes, labels):
     return
 
 
-def plot4(kk, frequencies, frequencies_disp, qpoints, x_labels):
+def plot4(kk, frequencies, frequencies_disp, qpoints, x_labels, ZQS):
     pgf_with_latex = {                      # setup matplotlib to use latex for output
 
     "pgf.texsystem": "pdflatex",        # change this if using xetex or lautex
@@ -664,7 +664,11 @@ def plot4(kk, frequencies, frequencies_disp, qpoints, x_labels):
     }
 
     mpl.rcParams.update(pgf_with_latex)
-    fig, ax = plt.subplots()
+    fig = plt.figure()
+    gs = gridspec.GridSpec(1,4, wspace=0)
+    ax = fig.add_subplot(gs[0, 0:3])
+    plt.xticks(kk, x_labels)
+    ax2 = fig.add_subplot(gs[0, 3], sharey=ax)
     n_branches = len(frequencies[0,:,0])
     
     
@@ -704,9 +708,16 @@ def plot4(kk, frequencies, frequencies_disp, qpoints, x_labels):
     ax.set_ylabel('Frequency [Thz]')
     ax.tick_params(axis='both', which='major', labelsize=15, width=2 , length=6, direction='in', top=True, right=True)
     ax.axhline(0, linestyle='--', color='b')
+    
+    ax2.plot(np.sum(ZQS[:,1:], axis=1), ZQS[:,0], label='DOS')
+    ax2.set_xticks([])
+    ax2.tick_params(axis='y', which='major', labelsize=0.0001, width=2 , length=6, direction='in', top=True, right=True)
+    
+    
     plt.rcParams['axes.linewidth'] = 2
-    plt.xticks(kk, x_labels)
-    plt.legend(handles=[graph_disp, graph_ft])
+    ax.set_xticks(kk, x_labels)
+    ax.legend(handles=[graph_disp, graph_ft])
+    ax2.legend()
 #    plt.show()
     fig.savefig('plot4.pdf')
     return
