@@ -139,11 +139,16 @@ for mode in plot_types:
     
        
     if(mode==4):
+        freq = np.loadtxt('ZS', usecols=0)
+        meta = len(freq)
         # take the path the user inputs and find all the k points you can plot
         ks_path, x_labels, distances = read.read_path(kinput, Nqpoints, labels, Hk)
         frequencies = np.zeros((2,tot_atoms_uc*3,len(ks_path)))
         frequencies_disp = np.zeros((1,tot_atoms_uc*3,len(ks_path)))
-        count = 0
+        ZQS = np.zeros((meta, 1+len(ks_path))) #for the DOS
+        
+        count_DOS, count = 0, 0
+        accepted_qpoints = []
         for i in range(Nqpoints):
             to_skip = (4)*i
             qpoint = np.genfromtxt('quasiparticles',skip_header=to_skip+0, max_rows=1)
@@ -154,9 +159,17 @@ for mode in plot_types:
                 frequencies[:,:,count] = omegas_gammas
                 frequencies_disp[:,:,count] = freqs_disp[index_disp,:]
                 count = count + 1
-                
             
-        plot.plot4(distances, frequencies, frequencies_disp, ks_path, x_labels)
+            to_skip_DOS = (1+meta)*i
+            for j in range(len(ks_path)):
+                if(np.allclose(qpoint, ks_path[j]) and (qpoint.tolist() not in accepted_qpoints)):
+                    accepted_qpoints.append(qpoint.tolist())
+                    Zq = np.genfromtxt('Zqs',skip_header=to_skip_DOS+1, max_rows=meta)
+                    ZQS[:,count_DOS+1] = Zq[:,0]
+                    count_DOS = count_DOS + 1
+                
+        ZQS[:,0] = np.loadtxt('ZS', usecols=0)    
+        plot.plot4(distances, frequencies, frequencies_disp, ks_path, x_labels, ZQS)
     
     if(mode==5):
         # take the path the user inputs and find all the k points you can plot
