@@ -81,19 +81,21 @@ def read_post_proc(input_file):
     
     max_Z = float(lista[4])
     
-    ks = lista[5]
+    freq_res = float(lista[5])
+    
+    ks = lista[6]
     a = np.fromstring(ks, dtype=np.float, sep=',')
     num = len(a)/3
     kpoints = np.split(a,num)
     
-    labs = lista[6]
+    labs = lista[7]
     labels = labs.split(',')
     
-    modes = np.fromstring(lista[7], dtype=np.int, sep=',')
+    modes = np.fromstring(lista[8], dtype=np.int, sep=',')
     
-    temperature_folders = lista[8]
+    temperature_folders = lista[9]
     
-    return plot_types, n_atom_unit_cell, file_eigenvectors, max_Z, kpoints, labels, modes, temperature_folders
+    return plot_types, n_atom_unit_cell, file_eigenvectors, max_Z, freq_res, kpoints, labels, modes, temperature_folders
 
 
 
